@@ -143,7 +143,10 @@ class CogMeta(type):
 
         commands = {}
         listeners = {}
-        no_bot_cog = "Commands or listeners must not start with cog_ or bot_ (in method {0.__name__}.{1})"
+        no_bot_cog = (
+            "Commands or listeners must not start with cog_ or bot_ (in method"
+            " {0.__name__}.{1})"
+        )
 
         new_cls = super().__new__(cls, name, bases, attrs, **kwargs)
 
@@ -177,7 +180,8 @@ class CogMeta(type):
                 if isinstance(value, _filter):
                     if is_static_method:
                         raise TypeError(
-                            f"Command in method {base}.{elem!r} must not be staticmethod."
+                            f"Command in method {base}.{elem!r} must not be"
+                            " staticmethod."
                         )
                     if elem.startswith(("cog_", "bot_")):
                         raise TypeError(no_bot_cog.format(base, elem))
@@ -187,13 +191,15 @@ class CogMeta(type):
                 if hasattr(value, "add_to") and not getattr(value, "parent", None):
                     if is_static_method:
                         raise TypeError(
-                            f"Command in method {base}.{elem!r} must not be staticmethod."
+                            f"Command in method {base}.{elem!r} must not be"
+                            " staticmethod."
                         )
                     if elem.startswith(("cog_", "bot_")):
                         raise TypeError(no_bot_cog.format(base, elem))
 
                     commands[f"ext_{elem}"] = value.ext_variant
                     commands[f"app_{elem}"] = value.slash_variant
+                    commands[elem] = value
                     for cmd in getattr(value, "subcommands", []):
                         commands[
                             f"ext_{cmd.ext_variant.qualified_name}"
@@ -224,9 +230,13 @@ class CogMeta(type):
 
         # Either update the command with the cog provided defaults or copy it.
         # r.e type ignore, type-checker complains about overriding a ClassVar
-        new_cls.__cog_commands__ = tuple(c._update_copy(cmd_attrs) for c in new_cls.__cog_commands__)  # type: ignore
+        new_cls.__cog_commands__ = tuple(c._update_copy(cmd_attrs) if not hasattr(c, "add_to") else c for c in new_cls.__cog_commands__)  # type: ignore
 
-        name_filter = lambda c: "app" if isinstance(c, ApplicationCommand) else "ext"
+        name_filter = (
+            lambda c: "app"
+            if isinstance(c, ApplicationCommand)
+            else ("bridge" if not hasattr(c, "add_to") else "ext")
+        )
 
         lookup = {
             f"{name_filter(cmd)}_{cmd.qualified_name}": cmd
@@ -242,7 +252,9 @@ class CogMeta(type):
             ):
                 command.guild_ids = new_cls.__cog_guild_ids__
 
-            if not isinstance(command, SlashCommandGroup):
+            if not isinstance(command, SlashCommandGroup) and not hasattr(
+                command, "add_to"
+            ):
                 # ignore bridge commands
                 cmd = getattr(new_cls, command.callback.__name__, None)
                 if hasattr(cmd, "add_to"):
@@ -321,12 +333,12 @@ class Cog(metaclass=CogMeta):
 
     @property
     def qualified_name(self) -> str:
-        """:class:`str`: Returns the cog's specified name, not the class name."""
+        """Returns the cog's specified name, not the class name."""
         return self.__cog_name__
 
     @property
     def description(self) -> str:
-        """:class:`str`: Returns the cog's description, typically the cleaned docstring."""
+        """Returns the cog's description, typically the cleaned docstring."""
         return self.__cog_description__
 
     @description.setter
@@ -386,7 +398,8 @@ class Cog(metaclass=CogMeta):
 
         if name is not MISSING and not isinstance(name, str):
             raise TypeError(
-                f"Cog.listener expected str but received {name.__class__.__name__!r} instead."
+                "Cog.listener expected str but received"
+                f" {name.__class__.__name__!r} instead."
             )
 
         def decorator(func: FuncT) -> FuncT:
@@ -410,7 +423,7 @@ class Cog(metaclass=CogMeta):
         return decorator
 
     def has_error_handler(self) -> bool:
-        """:class:`bool`: Checks whether the cog has an error handler.
+        """Checks whether the cog has an error handler.
 
         .. versionadded:: 1.7
         """
@@ -528,11 +541,18 @@ class Cog(metaclass=CogMeta):
         # we've added so far for some form of atomic loading.
 
         for index, command in enumerate(self.__cog_commands__):
+            if hasattr(command, "add_to"):
+                bot._bridge_commands.append(command)
+                continue
+
             command._set_cog(self)
 
             if isinstance(command, ApplicationCommand):
                 if isinstance(command, discord.SlashCommandGroup):
-                    for x in command.walk_commands():
+                    for x in command.subcommands:
+                        if isinstance(x, discord.SlashCommandGroup):
+                            for y in x.subcommands:
+                                y.parent = x
                         x.parent = command
                 bot.add_application_command(command)
 
@@ -689,7 +709,7 @@ class CogMixin:
 
     @property
     def cogs(self) -> Mapping[str, Cog]:
-        """Mapping[:class:`str`, :class:`Cog`]: A read-only mapping of cog name to cog."""
+        """A read-only mapping of cog name to cog."""
         return types.MappingProxyType(self.__cogs)
 
     # extensions
@@ -1111,5 +1131,5 @@ class CogMixin:
 
     @property
     def extensions(self) -> Mapping[str, types.ModuleType]:
-        """Mapping[:class:`str`, :class:`py:types.ModuleType`]: A read-only mapping of extension name to extension."""
+        """A read-only mapping of extension name to extension."""
         return types.MappingProxyType(self.__extensions)
