@@ -126,7 +126,7 @@ class BridgeContext(ABC):
 
     @property
     def is_app(self) -> bool:
-        """bool: Whether the context is an :class:`BridgeApplicationContext` or not."""
+        """Whether the context is an :class:`BridgeApplicationContext` or not."""
         return isinstance(self, BridgeApplicationContext)
 
 
