@@ -182,7 +182,9 @@ class HTTPClient:
         self.proxy_auth: aiohttp.BasicAuth | None = proxy_auth
         self.use_clock: bool = not unsync_clock
 
-        user_agent = "DiscordBot (https://github.com/Pycord-Development/pycord {0}) Python/{1[0]}.{1[1]} aiohttp/{2}"
+        user_agent = (
+            "DiscordBot (https://pycord.dev, {0}) Python/{1[0]}.{1[1]} aiohttp/{2}"
+        )
         self.user_agent: str = user_agent.format(
             __version__, sys.version_info, aiohttp.__version__
         )
@@ -299,7 +301,8 @@ class HTTPClient:
                                 response, use_clock=self.use_clock
                             )
                             _log.debug(
-                                "A rate limit bucket has been exhausted (bucket: %s, retry: %s).",
+                                "A rate limit bucket has been exhausted (bucket: %s,"
+                                " retry: %s).",
                                 bucket,
                                 delta,
                             )
@@ -317,7 +320,10 @@ class HTTPClient:
                                 # Banned by Cloudflare more than likely.
                                 raise HTTPException(response, data)
 
-                            fmt = 'We are being rate limited. Retrying in %.2f seconds. Handled under the bucket "%s"'
+                            fmt = (
+                                "We are being rate limited. Retrying in %.2f seconds."
+                                ' Handled under the bucket "%s"'
+                            )
 
                             # sleep a bit
                             retry_after: float = data["retry_after"]
@@ -327,7 +333,8 @@ class HTTPClient:
                             is_global = data.get("global", False)
                             if is_global:
                                 _log.warning(
-                                    "Global rate limit has been hit. Retrying in %.2f seconds.",
+                                    "Global rate limit has been hit. Retrying in %.2f"
+                                    " seconds.",
                                     retry_after,
                                 )
                                 self._global_over.clear()
@@ -896,7 +903,8 @@ class HTTPClient:
             params["delete_message_seconds"] = delete_message_seconds
         elif delete_message_days:
             warn_deprecated(
-                "delete_message_days" "delete_message_seconds",
+                "delete_message_days",
+                "delete_message_seconds",
                 "2.2",
                 reference="https://github.com/discord/discord-api-docs/pull/5219",
             )
@@ -1035,6 +1043,12 @@ class HTTPClient:
             "locked",
             "invitable",
             "default_auto_archive_duration",
+            "flags",
+            "default_thread_rate_limit_per_user",
+            "default_reaction_emoji",
+            "available_tags",
+            "applied_tags",
+            "default_sort_order",
         )
         payload = {k: v for k, v in options.items() if k in valid_keys}
         return self.request(r, reason=reason, json=payload)
@@ -1149,6 +1163,7 @@ class HTTPClient:
         auto_archive_duration: threads.ThreadArchiveDuration,
         rate_limit_per_user: int,
         invitable: bool = True,
+        applied_tags: SnowflakeList | None = None,
         reason: str | None = None,
         embed: embed.Embed | None = None,
         embeds: list[embed.Embed] | None = None,
@@ -1165,6 +1180,9 @@ class HTTPClient:
         if content:
             payload["content"] = content
 
+        if applied_tags:
+            payload["applied_tags"] = applied_tags
+
         if embed:
             payload["embeds"] = [embed]
 
@@ -2582,7 +2600,6 @@ class HTTPClient:
         embeds: list[embed.Embed] | None = None,
         allowed_mentions: message.AllowedMentions | None = None,
     ):
-
         payload: dict[str, Any] = {}
         if content:
             payload["content"] = content
